#
# spec file for package QLog
#
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>:
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           QLog
Version:        0.45.0
Release:        12.1
Summary:        Amateur radio logbook software
License:        GPL-3.0-or-later
Group:          Productivity/Hamradio/Other
URL:            https://github.com/foldynl/QLog
Source:         %{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Keychain)
BuildRequires:  pkgconfig(Qt6Charts)
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6DBus)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6SerialPort)
BuildRequires:  pkgconfig(Qt6Sql)
BuildRequires:  pkgconfig(Qt6WebEngineWidgets)
BuildRequires:  pkgconfig(Qt6WebSockets)
BuildRequires:  pkgconfig(Qt6Xml)
BuildRequires:  pkgconfig(hamlib)
BuildRequires:  pkgconfig(sqlite3)

%description
QLog is an Amateur Radio logging application. It is based on the Qt framework
and uses SQLite as database backend.

QLogs aims to be as simple as possible, but to provide everything the operator
expects from the log to be. This log is not currently focused on contests.

%prep
%autosetup -p1

%build
%{qmake6} \
	PREFIX=%{_prefix} \
	%{nil}
%make_build

%install
%make_install \
	INSTALL_ROOT=%{buildroot} \
	%{nil}

%files
%license LICENSE
%doc AUTHORS README.md Changelog
%{_bindir}/qlog
%{_datadir}/applications/qlog.desktop
%{_datadir}/icons/hicolor
%{_datadir}/metainfo/io.github.foldynl.QLog.metainfo.xml

%changelog
* Sat Jul 12 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.45.0:
  * Single Dialog for Upload/Download Online Services
  * Added option to swap paddles to Winkey settings
  * Added native support for the FLRig interface
  * QRZ Upload - Added support for multiple API Keys
  * Added highlighting to the filter button when a filter is active
  * WSJTX/DXC: Filtered label is shown when filter is enabled
  * Added support to Upload Cloudlog/Wavelog
  * Add JS8 to legacy_modes.json
  * Unification Settings storage
  * Calculate distances according to IARU rules
  * Fixed missing Wsjtx Spot values in the AlertWindow
* Sun May 11 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.44.1:
  * Fix SegFault in Rotator Widget
* Fri May  9 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.44.0:
  * Activity Manager - Added SKCC, UKSMG and FISTS as Dynamic Fields
  * QSO - FISTS, SKCC, and UKSMG are auto-filled from MembershipQE
  * Rotator - Added QSO destination needle
  * QSO Detail - Adds grayline and short path
  * Rotator - Needle colors correspond to the online map
  * Fixed TCI cw_macros must contain RigID
  * Fixed TCI setKeySpeed sets keyer and macros speed
  * Fixed Data mode missing in rig control window - rigctld
  * Improved DXC Mode detection
  * Updated Simplified Chinese translation
* Sun Apr 20 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.43.1:
  * Fix click on PHONE DX Spots setting wrong mode
  * Fix no freq via Omnirig for IC7400
* Sat Apr  5 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.43.0:
  * Added support to receive QSOs from CSN SAT Device
  * Multiple independent bandmap windows
  * Winkey Keyer driver currently supports v1 and v2 hardware
  * QSLs QSLr Msg is editable
  * QSL Message Send
  * Enabled Power, RIT, XIT, Morse for RIG Netctl
  * QSLMSG replaced by QSLMSG_RCVD
  * Added an option to choose a QSLMsg field
  * eQSL QSLMSG is stored to QLog QSLMSG_RCVD
  * eQSL message is appended
  * Fixed Speed pot doesn't seem to work with a WinKeyer; double chars
  * Fixed BandMap Spots colour change after a QSO
  * Fixed Incorrect Field Mapping for Received eQSL Messages
* Sun Mar 23 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.42.2:
  * UI fixes, and various functional fixes
* Sun Mar  2 2025 Andreas Stieger <andreas.stieger@gmx.de>
- initial package 0.41.1
